@@ -1,6 +1,6 @@
 /*
  * Copyright (c) [2011-2014] Novell, Inc.
- * Copyright (c) [2016,2018] SUSE LLC
+ * Copyright (c) [2016-2021] SUSE LLC
  *
  * All Rights Reserved.
  *
@@ -30,6 +30,7 @@
 #include "snapper/Snapper.h"
 
 #include "utils/Range.h"
+#include "utils/Limit.h"
 #include "utils/equal-date.h"
 #include "utils/HumanString.h"
 #include "cleanup.h"
@@ -46,8 +47,18 @@ struct Parameters
     virtual bool is_degenerated() const { return true; }
 
     time_t min_age;
-    double space_limit;
-    double free_limit;
+    MaxUsedLimit space_limit;
+    MinFreeLimit free_limit;
+
+
+    void read(const ProxyConfig& config, const char* name, long int& value)
+    {
+	const map<string, string>& raw = config.getAllValues();
+	map<string, string>::const_iterator pos = raw.find(name);
+	if (pos != raw.end())
+	    pos->second >> value;
+    }
+
 
     template<typename Type>
     void read(const ProxyConfig& config, const char* name, Type& value)
@@ -55,11 +66,31 @@ struct Parameters
 	const map<string, string>& raw = config.getAllValues();
 	map<string, string>::const_iterator pos = raw.find(name);
 	if (pos != raw.end())
-	    pos->second >> value;
+	{
+	    try
+	    {
+		value.parse(pos->second);
+	    }
+	    catch (const Exception& e)
+	    {
+		SN_CAUGHT(e);
+
+		cerr << "failed to parse \"" << pos->second << "\" for \"" << name << "\"" << endl;
+	    }
+	}
     }
 };
 
 
+ostream&
+operator<<(ostream& s, const Parameters& parameters)
+{
+    return s << "min-age:" << parameters.min_age << '\n'
+	     << "space-limit:" << parameters.space_limit << '\n'
+	     << "free-limit:" << parameters.free_limit;
+}
+
+
 Parameters::Parameters(const ProxySnapper* snapper)
     : min_age(1800), space_limit(0.5), free_limit(0.2)
 {
@@ -70,15 +101,6 @@ Parameters::Parameters(const ProxySnapper* snapper)
 }
 
 
-ostream&
-operator<<(ostream& s, const Parameters& parameters)
-{
-    return s << "min-age:" << parameters.min_age << endl
-	     << "space-limit:" << parameters.space_limit
-	     << "free-limit:" << parameters.free_limit;
-}
-
-
 class Cleaner
 {
 public:
@@ -89,11 +111,12 @@ public:
     virtual ~Cleaner() {}
 
     void cleanup();
+    void cleanup(std::function<bool()> condition);
 
 protected:
 
     virtual list<ProxySnapshots::iterator> calculate_candidates(ProxySnapshots& snapshots,
-								Range::Value value) = 0;
+								const Range::Value& value) = 0;
 
     struct younger_than
     {
@@ -134,8 +157,8 @@ protected:
     void cleanup(ProxySnapshots& snapshots, std::function<bool()> condition);
 
     ProxySnapper* snapper;
-    bool verbose;
 
+    const bool verbose;
     const Parameters& parameters;
 
 };
@@ -244,7 +267,7 @@ Cleaner::is_quota_aware() const
 	return false;
     }
 
-    return parameters.space_limit < 1.0;
+    return parameters.space_limit.is_enabled();
 }
 
 
@@ -256,14 +279,12 @@ Cleaner::is_quota_satisfied() const
     if (quota_data.size == 0)
 	return true;
 
-    double fraction = (double)(quota_data.used) / (double)(quota_data.size);
-
-    bool satisfied = fraction < parameters.space_limit;
+    bool satisfied = parameters.space_limit.is_satisfied(quota_data.size, quota_data.used);
 
 #ifdef VERBOSE_LOGGING
-    cout << byte_to_humanstring(quota_data.size, 2) << ", "
-	 << byte_to_humanstring(quota_data.used, 2) << ", "
-	 << fraction << ", " << satisfied << endl;
+    cout << byte_to_humanstring(quota_data.size, true, 2) << ", "
+	 << byte_to_humanstring(quota_data.used, true, 2) << ", "
+	 << satisfied << '\n';
 #endif
 
     return satisfied;
@@ -288,7 +309,7 @@ Cleaner::is_free_aware() const
 	return false;
     }
 
-    return parameters.free_limit > 0.0;
+    return parameters.free_limit.is_enabled();
 }
 
 
@@ -300,14 +321,12 @@ Cleaner::is_free_satisfied() const
     if (free_space_data.size == 0)
 	return true;
 
-    double fraction = (double)(free_space_data.free) / (double)(free_space_data.size);
-
-    bool satisfied = fraction > parameters.free_limit;
+    bool satisfied = parameters.free_limit.is_satisfied(free_space_data.size, free_space_data.free);
 
 #ifdef VERBOSE_LOGGING
-    cout << byte_to_humanstring(free_space_data.size, 2) << ", "
-	 << byte_to_humanstring(free_space_data.free, 2) << ", "
-	 << fraction << ", " << satisfied << endl;
+    cout << byte_to_humanstring(free_space_data.size, true, 2) << ", "
+	 << byte_to_humanstring(free_space_data.free, true, 2) << ", "
+	 << satisfied << '\n';
 #endif
 
     return satisfied;
@@ -336,7 +355,7 @@ Cleaner::cleanup(ProxySnapshots& snapshots, std::function<bool()> condition)
 	    // not enough candidates to satisfy the condition
 
 #ifdef VERBOSE_LOGGING
-	    cout << "condition not satisfied" << endl;
+	    cout << "condition not satisfied" << '\n';
 #endif
 
 	    return;
@@ -366,7 +385,7 @@ Cleaner::cleanup(ProxySnapshots& snapshots, std::function<bool()> condition)
 		// not enough candidates to satisfy the condition
 
 #ifdef VERBOSE_LOGGING
-		cout << "condition not satisfied" << endl;
+		cout << "condition not satisfied" << '\n';
 #endif
 
 		return;
@@ -375,7 +394,7 @@ Cleaner::cleanup(ProxySnapshots& snapshots, std::function<bool()> condition)
     }
 
 #ifdef VERBOSE_LOGGING
-    cout << "condition satisfied" << endl;
+    cout << "condition satisfied" << '\n';
 #endif
 }
 
@@ -386,7 +405,7 @@ Cleaner::cleanup()
     ProxySnapshots& snapshots = snapper->getSnapshots();
 
 #ifdef VERBOSE_LOGGING
-    cout << "cleanup without condition" << endl;
+    cout << "cleanup without condition" << '\n';
 #endif
 
     cleanup(snapshots);
@@ -394,7 +413,7 @@ Cleaner::cleanup()
     if (is_quota_aware())
     {
 #ifdef VERBOSE_LOGGING
-	cout << "cleanup with quota condition" << endl;
+	cout << "cleanup with quota condition" << '\n';
 #endif
 
 	cleanup(snapshots, std::bind(&Cleaner::is_quota_satisfied, this));
@@ -402,14 +421,14 @@ Cleaner::cleanup()
     else
     {
 #ifdef VERBOSE_LOGGING
-	cout << "no cleanup with quota condition" << endl;
+	cout << "no cleanup with quota condition" << '\n';
 #endif
     }
 
     if (is_free_aware())
     {
 #ifdef VERBOSE_LOGGING
-	cout << "cleanup with free condition" << endl;
+	cout << "cleanup with free condition" << '\n';
 #endif
 
 	cleanup(snapshots, std::bind(&Cleaner::is_free_satisfied, this));
@@ -417,12 +436,25 @@ Cleaner::cleanup()
     else
     {
 #ifdef VERBOSE_LOGGING
-	cout << "no cleanup with free condition" << endl;
+	cout << "no cleanup with free condition" << '\n';
 #endif
     }
 }
 
 
+void
+Cleaner::cleanup(std::function<bool()> condition)
+{
+    ProxySnapshots& snapshots = snapper->getSnapshots();
+
+#ifdef VERBOSE_LOGGING
+    cout << "cleanup with user condition" << '\n';
+#endif
+
+    cleanup(snapshots, condition);
+}
+
+
 struct NumberParameters : public Parameters
 {
     NumberParameters(const ProxySnapper* snapper);
@@ -434,6 +466,15 @@ struct NumberParameters : public Parameters
 };
 
 
+ostream&
+operator<<(ostream& s, const NumberParameters& parameters)
+{
+    return s << dynamic_cast<const Parameters&>(parameters) << '\n'
+	     << "limit:" << parameters.limit << '\n'
+	     << "limit-important:" << parameters.limit_important;
+}
+
+
 NumberParameters::NumberParameters(const ProxySnapper* snapper)
     : Parameters(snapper), limit(50), limit_important(10)
 {
@@ -443,15 +484,10 @@ NumberParameters::NumberParameters(const ProxySnapper* snapper)
 
     read(config, "NUMBER_LIMIT", limit);
     read(config, "NUMBER_LIMIT_IMPORTANT", limit_important);
-}
 
-
-ostream&
-operator<<(ostream& s, const NumberParameters& parameters)
-{
-    return s << dynamic_cast<const Parameters&>(parameters) << endl
-	     << "limit:" << parameters.limit << endl
-	     << "limit-important:" << parameters.limit_important;
+#ifdef VERBOSE_LOGGING
+    cout << *this << '\n';
+#endif
 }
 
 
@@ -481,7 +517,7 @@ private:
 
 
     list<ProxySnapshots::iterator>
-    calculate_candidates(ProxySnapshots& snapshots, Range::Value value) override
+    calculate_candidates(ProxySnapshots& snapshots, const Range::Value& value) override
     {
 	const NumberParameters& parameters = dynamic_cast<const NumberParameters&>(Cleaner::parameters);
 
@@ -534,6 +570,15 @@ do_cleanup_number(ProxySnapper* snapper, bool verbose)
 }
 
 
+void
+do_cleanup_number(ProxySnapper* snapper, bool verbose, std::function<bool()> condition)
+{
+    NumberParameters parameters(snapper);
+    NumberCleaner cleaner(snapper, verbose, parameters);
+    cleaner.cleanup(condition);
+}
+
+
 struct TimelineParameters : public Parameters
 {
     TimelineParameters(const ProxySnapper* snapper);
@@ -548,6 +593,18 @@ struct TimelineParameters : public Parameters
 };
 
 
+ostream&
+operator<<(ostream& s, const TimelineParameters& parameters)
+{
+    return s << dynamic_cast<const Parameters&>(parameters) << '\n'
+	     << "limit-hourly:" << parameters.limit_hourly << '\n'
+	     << "limit-daily:" << parameters.limit_daily << '\n'
+	     << "limit-weekly:" << parameters.limit_weekly << '\n'
+	     << "limit-monthly:" << parameters.limit_monthly << '\n'
+	     << "limit-yearly:" << parameters.limit_yearly;
+}
+
+
 TimelineParameters::TimelineParameters(const ProxySnapper* snapper)
     : Parameters(snapper), limit_hourly(10), limit_daily(10), limit_monthly(10),
       limit_weekly(0), limit_yearly(10)
@@ -561,18 +618,10 @@ TimelineParameters::TimelineParameters(const ProxySnapper* snapper)
     read(config, "TIMELINE_LIMIT_WEEKLY", limit_weekly);
     read(config, "TIMELINE_LIMIT_MONTHLY", limit_monthly);
     read(config, "TIMELINE_LIMIT_YEARLY", limit_yearly);
-}
 
-
-ostream&
-operator<<(ostream& s, const TimelineParameters& parameters)
-{
-    return s << dynamic_cast<const Parameters&>(parameters) << endl
-	     << "limit-hourly:" << parameters.limit_hourly << endl
-	     << "limit-daily:" << parameters.limit_daily << endl
-	     << "limit-weekly:" << parameters.limit_weekly << endl
-	     << "limit-monthly:" << parameters.limit_monthly << endl
-	     << "limit-yearly:" << parameters.limit_yearly;
+#ifdef VERBOSE_LOGGING
+    cout << *this << '\n';
+#endif
 }
 
 
@@ -666,7 +715,7 @@ private:
 
 
     list<ProxySnapshots::iterator>
-    calculate_candidates(ProxySnapshots& snapshots, Range::Value value) override
+    calculate_candidates(ProxySnapshots& snapshots, const Range::Value& value) override
     {
 	const TimelineParameters& parameters = dynamic_cast<const TimelineParameters&>(Cleaner::parameters);
 
@@ -737,6 +786,15 @@ do_cleanup_timeline(ProxySnapper* snapper, bool verbose)
 }
 
 
+void
+do_cleanup_timeline(ProxySnapper* snapper, bool verbose, std::function<bool()> condition)
+{
+    TimelineParameters parameters(snapper);
+    TimelineCleaner cleaner(snapper, verbose, parameters);
+    cleaner.cleanup(condition);
+}
+
+
 struct EmptyPrePostParameters : public Parameters
 {
     EmptyPrePostParameters(const ProxySnapper* snapper);
@@ -749,6 +807,10 @@ EmptyPrePostParameters::EmptyPrePostParameters(const ProxySnapper* snapper)
     ProxyConfig config = snapper->getConfig();
 
     read(config, "EMPTY_PRE_POST_MIN_AGE", min_age);
+
+#ifdef VERBOSE_LOGGING
+    cout << *this << '\n';
+#endif
 }
 
 
@@ -763,7 +825,7 @@ public:
 private:
 
     list<ProxySnapshots::iterator>
-    calculate_candidates(ProxySnapshots& snapshots, Range::Value value) override
+    calculate_candidates(ProxySnapshots& snapshots, const Range::Value& value) override
     {
 	list<ProxySnapshots::iterator> ret;
 
@@ -796,3 +858,12 @@ do_cleanup_empty_pre_post(ProxySnapper* snapper, bool verbose)
     EmptyPrePostCleaner cleaner(snapper, verbose, parameters);
     cleaner.cleanup();
 }
+
+
+void
+do_cleanup_empty_pre_post(ProxySnapper* snapper, bool verbose, std::function<bool()> condition)
+{
+    EmptyPrePostParameters parameters(snapper);
+    EmptyPrePostCleaner cleaner(snapper, verbose, parameters);
+    cleaner.cleanup(condition);
+}
