@@ -1,5 +1,5 @@
 /*
- * Copyright (c) [2016-2019] SUSE LLC
+ * Copyright (c) [2016-2020] SUSE LLC
  *
  * All Rights Reserved.
  *
@@ -93,10 +93,11 @@ public:
 
     ProxySnapshotsDbus(ProxySnapperDbus* backref);
 
-    virtual iterator getDefault();
-    virtual const_iterator getDefault() const;
+    virtual iterator getDefault() override;
+    virtual const_iterator getDefault() const override;
 
-    virtual const_iterator getActive() const;
+    virtual iterator getActive() override;
+    virtual const_iterator getActive() const override;
 
     DBus::Connection& conn() const;
     const string& configName() const;
