@@ -1,6 +1,6 @@
 /*
  * Copyright (c) [2004-2015] Novell, Inc.
- * Copyright (c) [2016-2020] SUSE LLC
+ * Copyright (c) [2016-2021] SUSE LLC
  *
  * All Rights Reserved.
  *
@@ -147,10 +147,14 @@ namespace snapper
     string
     prepend_root_prefix(const string& root_prefix, const string& path)
     {
-        if (root_prefix == "/")
-            return path;
-        else
-            return root_prefix + path;
+	// TODO use std::filesystem (C++17)
+
+	if (root_prefix == "/" || root_prefix.empty())
+	    return path;
+	else if (path == "/")
+	    return root_prefix;
+	else
+	    return root_prefix + path;
     }
 
 
@@ -421,4 +425,29 @@ namespace snapper
 	return std::equal(std::begin(value), std::end(value), std::begin(rhs.value));
     }
 
+
+    bool
+    Uuid::operator<(const Uuid& rhs) const
+    {
+	return std::lexicographical_compare(std::begin(value), std::end(value),
+					    std::begin(rhs.value), std::end(rhs.value));
+    }
+
+
+    std::ostream&
+    operator<<(std::ostream& s, const Uuid& uuid)
+    {
+	for (int i = 0; i < 16; ++i)
+	{
+	    char buf[4];
+	    snprintf(buf, 4, "%02x", uuid.value[i]);
+	    s << buf;
+
+	    if (i == 3 || i == 5 || i == 7 || i == 9)
+		s << '-';
+	}
+
+	return s;
+    }
+
 }
