@@ -34,14 +34,14 @@ namespace snapper
     struct LvmActivationException : public std::exception
     {
 	explicit LvmActivationException() throw() {}
-	virtual const char* what() const throw() { return "lvm snapshot activation exception"; }
+	virtual const char* what() const throw() override { return "lvm snapshot activation exception"; }
     };
 
 
     struct LvmDeactivatationException : public std::exception
     {
 	explicit LvmDeactivatationException() throw() {}
-	virtual const char* what() const throw() { return "lvm snapshot deactivation exception"; }
+	virtual const char* what() const throw() override { return "lvm snapshot deactivation exception"; }
     };
 
 
@@ -71,7 +71,7 @@ namespace snapper
 	// empty or " -K" if lvm supports ignore activation skip flag
 	string ignoreactivationskip;
 	// true if lvm2 supports time info stored in metadata
-	bool time_support;
+	bool time_support = false;
     };
 
     class SelinuxLabelHandle;
@@ -85,28 +85,28 @@ namespace snapper
 
 	Lvm(const string& subvolume, const string& root_prefix, const string& mount_type);
 
-	virtual string fstype() const { return "lvm(" + mount_type + ")"; }
+	virtual string fstype() const override { return "lvm(" + mount_type + ")"; }
 
-	virtual void createConfig() const;
-	virtual void deleteConfig() const;
+	virtual void createConfig() const override;
+	virtual void deleteConfig() const override;
 
-	virtual string snapshotDir(unsigned int num) const;
+	virtual string snapshotDir(unsigned int num) const override;
 	virtual string snapshotLvName(unsigned int num) const;
 
-	virtual SDir openInfosDir() const;
-	virtual SDir openSnapshotDir(unsigned int num) const;
+	virtual SDir openInfosDir() const override;
+	virtual SDir openSnapshotDir(unsigned int num) const override;
 
 	virtual void createSnapshot(unsigned int num, unsigned int num_parent, bool read_only,
-				    bool quota, bool empty) const;
-	virtual void deleteSnapshot(unsigned int num) const;
+				    bool quota, bool empty) const override;
+	virtual void deleteSnapshot(unsigned int num) const override;
 
-	virtual bool isSnapshotMounted(unsigned int num) const;
-	virtual void mountSnapshot(unsigned int num) const;
-	virtual void umountSnapshot(unsigned int num) const;
+	virtual bool isSnapshotMounted(unsigned int num) const override;
+	virtual void mountSnapshot(unsigned int num) const override;
+	virtual void umountSnapshot(unsigned int num) const override;
 
-	virtual bool isSnapshotReadOnly(unsigned int num) const;
+	virtual bool isSnapshotReadOnly(unsigned int num) const override;
 
-	virtual bool checkSnapshot(unsigned int num) const;
+	virtual bool checkSnapshot(unsigned int num) const override;
 
     private:
 
